@@ -225,7 +225,7 @@ class ProjectMetadata(Generic[PluginManagerBound]):
         if version is None:
             version = self.hatch.version.cached
             source = f'source `{self.hatch.version.source_name}`'
-            core_metadata._version_set = True
+            core_metadata._version_set = True  # noqa: SLF001
         else:
             source = 'field `project.version`'
 
@@ -385,7 +385,8 @@ class CoreMetadata:
             if not raw_name:
                 message = 'Missing required field `project.name`'
                 raise ValueError(message)
-            elif not isinstance(raw_name, str):
+
+            if not isinstance(raw_name, str):
                 message = 'Field `project.name` must be a string'
                 raise TypeError(message)
 
@@ -462,8 +463,7 @@ class CoreMetadata:
             if not isinstance(description, str):
                 message = 'Field `project.description` must be a string'
                 raise TypeError(message)
-
-            self._description = description
+            self._description = ' '.join(description.splitlines())
 
         return self._description
 
@@ -518,10 +518,12 @@ class CoreMetadata:
                 if content_type is None:
                     message = 'Field `content-type` is required in the `project.readme` table'
                     raise ValueError(message)
-                elif not isinstance(content_type, str):
+
+                if not isinstance(content_type, str):
                     message = 'Field `content-type` in the `project.readme` table must be a string'
                     raise TypeError(message)
-                elif content_type not in ('text/markdown', 'text/x-rst', 'text/plain'):
+
+                if content_type not in {'text/markdown', 'text/x-rst', 'text/plain'}:
                     message = (
                         'Field `content-type` in the `project.readme` table must be one of the following: '
                         'text/markdown, text/x-rst, text/plain'
@@ -724,7 +726,8 @@ class CoreMetadata:
                 if not isinstance(data, dict):
                     message = 'Field `project.license-files` must be a table'
                     raise TypeError(message)
-                elif 'paths' in data and 'globs' in data:
+
+                if 'paths' in data and 'globs' in data:
                     message = 'Cannot specify both `paths` and `globs` in the `project.license-files` table'
                     raise ValueError(message)
 
@@ -760,9 +763,11 @@ class CoreMetadata:
                         raise TypeError(message)
 
                     full_pattern = os.path.normpath(os.path.join(self.root, pattern))
-                    for path in glob(full_pattern):
-                        if os.path.isfile(path):
-                            license_files.append(os.path.relpath(path, self.root).replace('\\', '/'))
+                    license_files.extend(
+                        os.path.relpath(path, self.root).replace('\\', '/')
+                        for path in glob(full_pattern)
+                        if os.path.isfile(path)
+                    )
             else:
                 message = 'Must specify either `paths` or `globs` in the `project.license-files` table if defined'
                 raise ValueError(message)
@@ -950,7 +955,7 @@ class CoreMetadata:
         if self._classifiers is None:
             import bisect
 
-            from hatchling.metadata.classifiers import KNOWN_CLASSIFIERS, SORTED_CLASSIFIERS, is_private
+            import trove_classifiers
 
             if 'classifiers' in self.config:
                 classifiers = self.config['classifiers']
@@ -967,25 +972,26 @@ class CoreMetadata:
                 message = 'Field `project.classifiers` must be an array'
                 raise TypeError(message)
 
-            known_classifiers = KNOWN_CLASSIFIERS | self._extra_classifiers
+            known_classifiers = trove_classifiers.classifiers | self._extra_classifiers
             unique_classifiers = set()
 
             for i, classifier in enumerate(classifiers, 1):
                 if not isinstance(classifier, str):
                     message = f'Classifier #{i} of field `project.classifiers` must be a string'
                     raise TypeError(message)
-                elif not is_private(classifier) and classifier not in known_classifiers:
+
+                if not self.__classifier_is_private(classifier) and classifier not in known_classifiers:
                     message = f'Unknown classifier in field `project.classifiers`: {classifier}'
                     raise ValueError(message)
 
                 unique_classifiers.add(classifier)
 
-            sorted_classifiers = list(SORTED_CLASSIFIERS)
-            for classifier in sorted(self._extra_classifiers - KNOWN_CLASSIFIERS):
+            sorted_classifiers = list(trove_classifiers.sorted_classifiers)
+            for classifier in sorted(self._extra_classifiers - trove_classifiers.classifiers):
                 bisect.insort(sorted_classifiers, classifier)
 
             self._classifiers = sorted(
-                unique_classifiers, key=lambda c: -1 if is_private(c) else sorted_classifiers.index(c)
+                unique_classifiers, key=lambda c: -1 if self.__classifier_is_private(c) else sorted_classifiers.index(c)
             )
 
         return self._classifiers
@@ -1112,10 +1118,10 @@ class CoreMetadata:
                 message = 'Field `project.entry-points` must be a table'
                 raise TypeError(message)
 
-            for forbidden_field in ('scripts', 'gui-scripts'):
+            for forbidden_field, expected_field in (('console_scripts', 'scripts'), ('gui-scripts', 'gui-scripts')):
                 if forbidden_field in defined_entry_point_groups:
                     message = (
-                        f'Field `{forbidden_field}` must be defined as `project.{forbidden_field}` '
+                        f'Field `{forbidden_field}` must be defined as `project.{expected_field}` '
                         f'instead of in the `project.entry-points` table'
                     )
                     raise ValueError(message)
@@ -1188,7 +1194,7 @@ class CoreMetadata:
 
                     dependencies_complex[get_normalized_dependency(requirement)] = requirement
 
-            self._dependencies_complex = {k: v for k, v in sorted(dependencies_complex.items())}
+            self._dependencies_complex = dict(sorted(dependencies_complex.items()))
 
         return self._dependencies_complex
 
@@ -1236,7 +1242,8 @@ class CoreMetadata:
                         f'ASCII letters/digits.'
                     )
                     raise ValueError(message)
-                elif not isinstance(dependencies, list):
+
+                if not isinstance(dependencies, list):
                     message = (
                         f'Dependencies for option `{option}` of field `project.optional-dependencies` must be an array'
                     )
@@ -1282,9 +1289,9 @@ class CoreMetadata:
                     raise ValueError(message)
 
                 normalized_options[normalized_option] = option
-                optional_dependency_entries[normalized_option] = {k: v for k, v in sorted(entries.items())}
+                optional_dependency_entries[normalized_option] = dict(sorted(entries.items()))
 
-            self._optional_dependencies_complex = {k: v for k, v in sorted(optional_dependency_entries.items())}
+            self._optional_dependencies_complex = dict(sorted(optional_dependency_entries.items()))
 
         return self._optional_dependencies_complex
 
@@ -1311,7 +1318,8 @@ class CoreMetadata:
         if not isinstance(self._dynamic, list):
             message = 'Field `project.dynamic` must be an array'
             raise TypeError(message)
-        elif not all(isinstance(entry, str) for entry in self._dynamic):
+
+        if not all(isinstance(entry, str) for entry in self._dynamic):
             message = 'Field `project.dynamic` must only contain strings'
             raise TypeError(message)
 
@@ -1325,6 +1333,10 @@ class CoreMetadata:
         for attribute in dir(self):
             getattr(self, attribute)
 
+    @staticmethod
+    def __classifier_is_private(classifier: str) -> bool:
+        return classifier.lower().startswith('private ::')
+
 
 class HatchMetadata(Generic[PluginManagerBound]):
     def __init__(self, root: str, config: dict[str, dict[str, Any]], plugin_manager: PluginManagerBound) -> None:
@@ -1407,7 +1419,7 @@ class HatchVersionConfig(Generic[PluginManagerBound]):
         if self._cached is None:
             try:
                 self._cached = self.source.get_version_data()['version']
-            except Exception as e:
+            except Exception as e:  # noqa: BLE001
                 message = f'Error getting the version from source `{self.source.PLUGIN_NAME}`: {e}'
                 raise type(e)(message) from None
 
@@ -1420,7 +1432,8 @@ class HatchVersionConfig(Generic[PluginManagerBound]):
             if not source:
                 message = 'The `source` option under the `tool.hatch.version` table must not be empty if defined'
                 raise ValueError(message)
-            elif not isinstance(source, str):
+
+            if not isinstance(source, str):
                 message = 'Field `tool.hatch.version.source` must be a string'
                 raise TypeError(message)
 
@@ -1435,7 +1448,8 @@ class HatchVersionConfig(Generic[PluginManagerBound]):
             if not scheme:
                 message = 'The `scheme` option under the `tool.hatch.version` table must not be empty if defined'
                 raise ValueError(message)
-            elif not isinstance(scheme, str):
+
+            if not isinstance(scheme, str):
                 message = 'Field `tool.hatch.version.scheme` must be a string'
                 raise TypeError(message)
 
